# chuni scanner

**chuni scanner** is a companion project for [HarukiBot](https://github.com/Team-Haruki), it can scan all the chunithm music data and upsert to MySQL.

## Requirements
+ `Python >= 3.12`

## License

This project is licensed under the MIT License.